import { getCurrentInstance } from 'vue-demi';
import ziggy from 'ziggy-js';
import { useForm as _useForm, usePage as _usePage } from '@inertiajs/vue2';
import { InertiaLink, install } from './link';
/**
 * Get head manager instance
 */
export function useHeadManager() {
    /** Vue instance */
    const instance = getCurrentInstance();
    if (instance) {
        // @ts-ignore
        return instance.proxy.$headManager;
    }
    else {
        warn();
    }
    return undefined;
}
/**
 * Get page instance
 *
 * @deprecated use \@inertiajs/vue2's usePage().
 */
export function usePage() {
    /** Get Instance */
    const instance = getCurrentInstance();
    if (instance) {
        // @ts-ignore
        return instance.proxy.$page;
    }
    return _usePage();
}
/**
 * Get inertia instance
 */
export function useInertia() {
    /** Get Instance */
    const instance = getCurrentInstance();
    if (instance) {
        // @ts-ignore
        return instance.proxy.$inertia;
    }
    else {
        warn();
    }
    return undefined;
}
/**
 * Get Form
 *
 * @param data - Form Key-Value Pair.
 * @param rememberKey - Cancel token
 *
 * @deprecated use \@inertiajs/vue2's useForm()
 */
export function useForm(rememberKey, data) {
    /** Get Instance */
    const instance = getCurrentInstance();
    if (rememberKey) {
        return instance
            ? // @ts-ignore
                instance.proxy.$inertia.form(rememberKey, data)
            : _useForm(rememberKey, data);
    }
    return instance
        ? // @ts-ignore
            instance.proxy.$inertia.form(data)
        : _useForm(data);
}
/**
 * Get route instance.
 *
 * @param name - router name.
 * @param params - query strings key value pair.
 * @param absolute - return to absolute url flag.
 * @param config - override confing. (Host, Port, etc.)
 */
export function route(name, params, absolute, config) {
    /** Get Instance */
    const instance = getCurrentInstance();
    // @ts-ignore
    if (instance && instance.proxy.route) {
        // @ts-ignore
        return instance.proxy.route(name, params, absolute, config);
    }
    // if not instance get ziggy directly
    return ziggy(name, params, absolute, config);
}
/** output warn message. */
const warn = () => console.warn(`[Inertia Composable] getCurrentInstance() returned null. Method must be called at the top of a setup() function.`);
// For CDN.
// @ts-ignore
if (typeof window !== 'undefined') {
    // @ts-ignore
    window.route = route;
}
export { InertiaLink, install };
